# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import vantage
from vantage.api.costs_api import CostsApi  # noqa: E501
from vantage.rest import ApiException


class TestCostsApi(unittest.TestCase):
    """CostsApi unit test stubs"""

    def setUp(self):
        self.api = vantage.api.costs_api.CostsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_costs(self):
        """Test case for get_costs

        """
        pass

    def test_get_report(self):
        """Test case for get_report

        """
        pass

    def test_get_reports(self):
        """Test case for get_reports

        """
        pass


if __name__ == '__main__':
    unittest.main()
