# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import vantage
from vantage.models.products import Products  # noqa: E501
from vantage.rest import ApiException


class TestProducts(unittest.TestCase):
    """Products unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testProducts(self):
        """Test Products"""
        # FIXME: construct object with mandatory attributes with example values
        # model = vantage.models.products.Products()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
