# coding: utf-8

"""
    Vantage

    Vantage API  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@vantage.sh
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six

from vantage.configuration import Configuration


class Report(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'earliest_cost_date': 'str',
        'latest_cost_date': 'str',
        'created_at': 'str',
        'workspace': 'str'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'earliest_cost_date': 'earliest_cost_date',
        'latest_cost_date': 'latest_cost_date',
        'created_at': 'created_at',
        'workspace': 'workspace'
    }

    def __init__(self, id=None, title=None, earliest_cost_date=None, latest_cost_date=None, created_at=None, workspace=None, _configuration=None):  # noqa: E501
        """Report - a model defined in Swagger"""  # noqa: E501
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._id = None
        self._title = None
        self._earliest_cost_date = None
        self._latest_cost_date = None
        self._created_at = None
        self._workspace = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if earliest_cost_date is not None:
            self.earliest_cost_date = earliest_cost_date
        if latest_cost_date is not None:
            self.latest_cost_date = latest_cost_date
        if created_at is not None:
            self.created_at = created_at
        if workspace is not None:
            self.workspace = workspace

    @property
    def id(self):
        """Gets the id of this Report.  # noqa: E501


        :return: The id of this Report.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Report.


        :param id: The id of this Report.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this Report.  # noqa: E501

        The title of the cost report.  # noqa: E501

        :return: The title of this Report.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Report.

        The title of the cost report.  # noqa: E501

        :param title: The title of this Report.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def earliest_cost_date(self):
        """Gets the earliest_cost_date of this Report.  # noqa: E501

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-01-01 or 2021-01-01T00:00:00Z.  # noqa: E501

        :return: The earliest_cost_date of this Report.  # noqa: E501
        :rtype: str
        """
        return self._earliest_cost_date

    @earliest_cost_date.setter
    def earliest_cost_date(self, earliest_cost_date):
        """Sets the earliest_cost_date of this Report.

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-01-01 or 2021-01-01T00:00:00Z.  # noqa: E501

        :param earliest_cost_date: The earliest_cost_date of this Report.  # noqa: E501
        :type: str
        """

        self._earliest_cost_date = earliest_cost_date

    @property
    def latest_cost_date(self):
        """Gets the latest_cost_date of this Report.  # noqa: E501

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-31 or 2021-07-31T00:00:00Z.  # noqa: E501

        :return: The latest_cost_date of this Report.  # noqa: E501
        :rtype: str
        """
        return self._latest_cost_date

    @latest_cost_date.setter
    def latest_cost_date(self, latest_cost_date):
        """Sets the latest_cost_date of this Report.

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-31 or 2021-07-31T00:00:00Z.  # noqa: E501

        :param latest_cost_date: The latest_cost_date of this Report.  # noqa: E501
        :type: str
        """

        self._latest_cost_date = latest_cost_date

    @property
    def created_at(self):
        """Gets the created_at of this Report.  # noqa: E501

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T00:00:00Z.  # noqa: E501

        :return: The created_at of this Report.  # noqa: E501
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """Sets the created_at of this Report.

        The date and time, in UTC, the report was created. ISO 8601 Formatted - 2021-07-15 or 2021-07-15T00:00:00Z.  # noqa: E501

        :param created_at: The created_at of this Report.  # noqa: E501
        :type: str
        """

        self._created_at = created_at

    @property
    def workspace(self):
        """Gets the workspace of this Report.  # noqa: E501

        The name of the workspace the report is a part of.  # noqa: E501

        :return: The workspace of this Report.  # noqa: E501
        :rtype: str
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """Sets the workspace of this Report.

        The name of the workspace the report is a part of.  # noqa: E501

        :param workspace: The workspace of this Report.  # noqa: E501
        :type: str
        """

        self._workspace = workspace

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Report, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Report):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Report):
            return True

        return self.to_dict() != other.to_dict()
